@@ -13,9 +13,7 @@ use super::decibel::{
     coeff_to_db_clamped_neg_90_db_f32, coeff_to_db_clamped_neg_90_db_f64,
     db_to_coeff_clamped_neg_90_db_f32, db_to_coeff_clamped_neg_90_db_f64,
 };
-use super::{
-    RealFrames, SampleRate, Seconds, SmoothF32, SmoothF64, SmoothOutputF32, SmoothOutputF64,
-};
+use super::{Frames, SampleRate, Seconds, SmoothF32, SmoothF64, SmoothOutputF32, SmoothOutputF64};
 
 /// A good default value to use as `smooth_secs` parameter when creating a [`ParamF32`]/[`ParamF64`].
 ///
@@ -320,7 +318,7 @@ impl<const MAX_BLOCKSIZE: usize> ParamF32<MAX_BLOCKSIZE> {
     }
 
     /// Get the smoothed buffer of values for use in DSP.
-    pub fn smoothed(&mut self, frames: RealFrames) -> SmoothOutputF32<MAX_BLOCKSIZE> {
+    pub fn smoothed(&mut self, frames: Frames) -> SmoothOutputF32<MAX_BLOCKSIZE> {
         let new_normalized = self.shared_normalized.get();
         if self.normalized != new_normalized {
             self.normalized = new_normalized;
@@ -819,7 +817,7 @@ impl<const MAX_BLOCKSIZE: usize> ParamF64<MAX_BLOCKSIZE> {
     }
 
     /// Get the smoothed buffer of values for use in DSP.
-    pub fn smoothed(&mut self, frames: RealFrames) -> SmoothOutputF64<MAX_BLOCKSIZE> {
+    pub fn smoothed(&mut self, frames: Frames) -> SmoothOutputF64<MAX_BLOCKSIZE> {
         let new_normalized = self.shared_normalized.get();
         if self.normalized != new_normalized {
             self.normalized = new_normalized;
